<?php
/*
Plugin Name: Latest Widget

License: GPL2/MIT
*/

/**
 * Recent_Posts_Dated_Widget
 * Displays recent posts including the post date.
 *
 * Based on WP_Widget_Recent_Posts from wp-includes/default-widgets.php
 *
 * @since 0.1
 */
class Latest_Posts_Widget extends WP_Widget {

	function Latest_Posts_Widget() {
		$widget_ops = array('classname' => 'latest_posts_widget', 'description' => __( "Latest Posts Widget, designed to be used on front page") );
		$this->WP_Widget('latest-posts-dated', __('Latest Posts'), $widget_ops);
		$this->alt_option_name = 'recent_entries_dated_widget';

		add_action( 'save_post', array(&$this, 'flush_widget_cache') );
		add_action( 'deleted_post', array(&$this, 'flush_widget_cache') );
		add_action( 'switch_theme', array(&$this, 'flush_widget_cache') );
	}

	function widget($args, $instance) {
		$cache = wp_cache_get('recent_posts_dated_widget', 'widget');

		if ( !is_array($cache) )
			$cache = array();

		if ( isset($cache[$args['widget_id']]) ) {
			echo $cache[$args['widget_id']];
			return;
		}

		ob_start();
		extract($args);

		$title = apply_filters('widget_title', empty($instance['title']) ? __('Recent Posts') : $instance['title']);
		if ( !$number = (int) $instance['number'] )
			$number = 10;
		else if ( $number < 1 )
			$number = 1;
		else if ( $number > 15 )
			$number = 15;

		$r = new WP_Query(array('showposts' => $number, 'nopaging' => 0, 'post_status' => 'publish', 'caller_get_posts' => 1));
		if ($r->have_posts()) :
?>
		<?php echo $before_widget; ?>
		<?php if ( $title ) echo $before_title . $title . $after_title; ?>
		<?php $i = 0; ?>
		<div id="posts">
		<?php  while ($r->have_posts()) : $r->the_post(); ?>
		<div class="<?php if ( $i % 2) echo 'omega'; ?> latest_item" >
									
									
									<div class="post-meta">
											<div class="post-meta-written">
												<?php the_time('F j, Y'); ?> <?php _e('at','phomedia'); ?> <?php the_time() ?>, <?php _e('by','phomedia'); ?> <?php the_author_posts_link() ?>
											</div>
											<div class="post-meta-taxonomy">
												 <?php the_category(', ') ?><br/>
												<?php if (the_tags(__('Tags: ','phomedia'), ', ', ' ')); ?>
											</div>
											<div class="post-meta-comments">
												<?php comments_popup_link(__('No Comments','phomedia'), __('1 Comment','phomedia'), __('% Comments','phomedia')); ?>
											</div>
									</div><!--.postMeta-->

									<div class="heading">
										<h2><a href="<?php the_permalink() ?>" title="<?php the_title(); ?>" rel="bookmark">
											<?php $title = the_title('','', false);  if ($title != '') echo $title; else echo "Article"; ?></a>
										</h2>
																				
									</div>
									
									<div class="post-content">
										<?php /* if ( has_post_thumbnail()) : ?>
										<?php echo '<figure class="thumb">'; the_post_thumbnail(); echo '</figure>';  ?>
									<?php endif; */?>
									
									<?php
   ob_start();
   the_content(__('Read more','phomedia'));
   $postOutput = preg_replace('/<img[^>]+./','', ob_get_contents());
   ob_end_clean();
   echo $postOutput;
?>
								
									</div>
								
								</div>
		<?php $i++; endwhile; ?>
		</div>
		<?php echo $after_widget; ?>
<?php
			wp_reset_query();  // Restore global post data stomped by the_post().
		endif;

		$cache[$args['widget_id']] = ob_get_flush();
		wp_cache_add('recent_posts_dated_widget', $cache, 'widget');
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['number'] = (int) $new_instance['number'];
		$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset($alloptions['recent_entries_dated_widget']) )
			delete_option('recent_entries_dated_widget');

		return $instance;
	}

	function flush_widget_cache() {
		wp_cache_delete('recent_posts_dated_widget', 'widget');
	}

	function form( $instance ) {
		$title = isset($instance['title']) ? esc_attr($instance['title']) : '';
		if ( !isset($instance['number']) || !$number = (int) $instance['number'] )
			$number = 5;
?>
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></p>

		<p><label for="<?php echo $this->get_field_id('number'); ?>"><?php _e('Number of posts to show:'); ?></label>
		<input id="<?php echo $this->get_field_id('number'); ?>" name="<?php echo $this->get_field_name('number'); ?>" type="text" value="<?php echo $number; ?>" size="3" /><br />
		<small><?php _e('(at most 15)'); ?></small></p>
<?php
	}
}

/**
 * @since 0.1
 */
function Latest_Posts_init() {
	register_widget('Latest_Posts_Widget');
}

/**
 * @since 0.1
 */
add_action('widgets_init', 'Latest_Posts_init');

?>